jQuery.ScrollTo
Description: Demo of jQuery.scrollTo. Lightweight, cross-browser and highly customizable animated scrolling with jQuery, made by Ariel Flesler.
Keywords: javascript, jquery, plugins, scroll, scrollTo, smooth, animation, to, effect, ariel, flesler, window, overflow, element, navigation, customizable

# jQuery.ScrollTo by Ariel Flesler

### Links

- Project Page
- Main blog article
- All articles
- LocalScroll Demo
- SerialScroll Demo
- New Demo

Scroll the window to
Scroll to the # element inside this container

- 0

  back to top

- 1

  back to top

- 2

  back to top

- 3

  back to top

- 4

  back to top

- 5

  back to top

- 6

  back to top

- 7

  back to top

Scroll to the # element inside this container

- 0

  back to start

- 1

  back to start

- 2

  back to start

- 3

  back to start

- 4

  back to start

- 5

  back to start

- 6

  back to start

- 7

  back to start

- 8

  back to start

- 9

  back to start

- 10

  back to start

- 11

  back to start

- 12

  back to start

- 13

  back to start

- 14

  back to start

- 15

  back to start

Scroll to the # element inside this container

- 0

  back to start

- 1

  back to start

- 2

  back to start

- 3

  back to start

- 4

  back to start

- 5

  back to start

- 6

  back to start

- 7

  back to start

- 8

  back to start

- 9

  back to start

- 10

  back to start

- 11

  back to start

- 12

  back to start

- 13

  back to start

- 14

  back to start

- 15

  back to start

- 16

  back to start

- 17

  back to start

- 18

  back to start

- 19

  back to start

- 20

  back to start

- 21

  back to start

- 22

  back to start

- 23

  back to start

- 24

  back to start

- 25

  back to start

- 26

  back to start

- 27

  back to start

- 28

  back to start

- 29

  back to start